@@ -1361,7 +1361,6 @@ goa_fedora_provider_init (GoaFedoraProvider *provider)
 static void
 goa_fedora_provider_class_init (GoaFedoraProviderClass *fedora_class)
 {
-  static volatile GQuark goa_identity_manager_error_domain = 0;
   GoaProviderClass *provider_class;
 
   provider_class = GOA_PROVIDER_CLASS (fedora_class);
@@ -1381,6 +1380,5 @@ goa_fedora_provider_class_init (GoaFedoraProviderClass *fedora_class)
    * org.gnome.Identity.Manager.Error.* errors via
    * g_dbus_error_register_error_domain().
    */
-  goa_identity_manager_error_domain = GOA_IDENTITY_MANAGER_ERROR;
-  goa_identity_manager_error_domain; /* shut up -Wunused-but-set-variable */
+  goa_identity_manager_error_quark ();
 }
